==> zio-aws-pinpointemail_3-5.17.104.5-sources.jar: zio/aws/pinpointemail/model/PutConfigurationSetDeliveryOptionsRequest.scala <==
package zio.aws.pinpointemail.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.pinpointemail.model.primitives.{
  SendingPoolName,
  ConfigurationSetName
}
import scala.jdk.CollectionConverters.*
final case class PutConfigurationSetDeliveryOptionsRequest(
    configurationSetName: ConfigurationSetName,
    tlsPolicy: Option[zio.aws.pinpointemail.model.TlsPolicy] = None,
    sendingPoolName: Option[SendingPoolName] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpointemail.model.PutConfigurationSetDeliveryOptionsRequest = {
    import PutConfigurationSetDeliveryOptionsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpointemail.model.PutConfigurationSetDeliveryOptionsRequest
      .builder()
      .configurationSetName(
        ConfigurationSetName.unwrap(configurationSetName): java.lang.String
      )
      .optionallyWith(tlsPolicy.map(value => value.unwrap))(_.tlsPolicy)
      .optionallyWith(
        sendingPoolName.map(value =>
          SendingPoolName.unwrap(value): java.lang.String
        )
      )(_.sendingPoolName)
      .build()
  }
  def asReadOnly
      : zio.aws.pinpointemail.model.PutConfigurationSetDeliveryOptionsRequest.ReadOnly =
    zio.aws.pinpointemail.model.PutConfigurationSetDeliveryOptionsRequest
      .wrap(buildAwsValue())
}
object PutConfigurationSetDeliveryOptionsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpointemail.model.PutConfigurationSetDeliveryOptionsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.pinpointemail.model.PutConfigurationSetDeliveryOptionsRequest =
      zio.aws.pinpointemail.model.PutConfigurationSetDeliveryOptionsRequest(
        configurationSetName,
        tlsPolicy.map(value => value),
        sendingPoolName.map(value => value)
      )
    def configurationSetName: ConfigurationSetName
    def tlsPolicy: Option[zio.aws.pinpointemail.model.TlsPolicy]
    def sendingPoolName: Option[SendingPoolName]
    def getConfigurationSetName: ZIO[Any, Nothing, ConfigurationSetName] =
      ZIO.succeed(configurationSetName)
    def getTlsPolicy
        : ZIO[Any, AwsError, zio.aws.pinpointemail.model.TlsPolicy] =
      AwsError.unwrapOptionField("tlsPolicy", tlsPolicy)
    def getSendingPoolName: ZIO[Any, AwsError, SendingPoolName] =
      AwsError.unwrapOptionField("sendingPoolName", sendingPoolName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpointemail.model.PutConfigurationSetDeliveryOptionsRequest
  ) extends zio.aws.pinpointemail.model.PutConfigurationSetDeliveryOptionsRequest.ReadOnly {
    override val configurationSetName: ConfigurationSetName =
      zio.aws.pinpointemail.model.primitives
        .ConfigurationSetName(impl.configurationSetName())
    override val tlsPolicy: Option[zio.aws.pinpointemail.model.TlsPolicy] =
      scala
        .Option(impl.tlsPolicy())
        .map(value => zio.aws.pinpointemail.model.TlsPolicy.wrap(value))
    override val sendingPoolName: Option[SendingPoolName] = scala
      .Option(impl.sendingPoolName())
      .map(value =>
        zio.aws.pinpointemail.model.primitives.SendingPoolName(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpointemail.model.PutConfigurationSetDeliveryOptionsRequest
  ): zio.aws.pinpointemail.model.PutConfigurationSetDeliveryOptionsRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-pinpointemail_3-5.17.295.4-sources.jar: zio/aws/pinpointemail/model/PutConfigurationSetDeliveryOptionsRequest.scala <==
package zio.aws.pinpointemail.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.pinpointemail.model.primitives.{
  SendingPoolName,
  ConfigurationSetName
}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class PutConfigurationSetDeliveryOptionsRequest(
    configurationSetName: ConfigurationSetName,
    tlsPolicy: Optional[zio.aws.pinpointemail.model.TlsPolicy] =
      Optional.Absent,
    sendingPoolName: Optional[SendingPoolName] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpointemail.model.PutConfigurationSetDeliveryOptionsRequest = {
    import PutConfigurationSetDeliveryOptionsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpointemail.model.PutConfigurationSetDeliveryOptionsRequest
      .builder()
      .configurationSetName(
        ConfigurationSetName.unwrap(configurationSetName): java.lang.String
      )
      .optionallyWith(tlsPolicy.map(value => value.unwrap))(_.tlsPolicy)
      .optionallyWith(
        sendingPoolName.map(value =>
          SendingPoolName.unwrap(value): java.lang.String
        )
      )(_.sendingPoolName)
      .build()
  }
  def asReadOnly
      : zio.aws.pinpointemail.model.PutConfigurationSetDeliveryOptionsRequest.ReadOnly =
    zio.aws.pinpointemail.model.PutConfigurationSetDeliveryOptionsRequest
      .wrap(buildAwsValue())
}
object PutConfigurationSetDeliveryOptionsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpointemail.model.PutConfigurationSetDeliveryOptionsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.pinpointemail.model.PutConfigurationSetDeliveryOptionsRequest =
      zio.aws.pinpointemail.model.PutConfigurationSetDeliveryOptionsRequest(
        configurationSetName,
        tlsPolicy.map(value => value),
        sendingPoolName.map(value => value)
      )
    def configurationSetName: ConfigurationSetName
    def tlsPolicy: Optional[zio.aws.pinpointemail.model.TlsPolicy]
    def sendingPoolName: Optional[SendingPoolName]
    def getConfigurationSetName: ZIO[Any, Nothing, ConfigurationSetName] =
      ZIO.succeed(configurationSetName)
    def getTlsPolicy
        : ZIO[Any, AwsError, zio.aws.pinpointemail.model.TlsPolicy] =
      AwsError.unwrapOptionField("tlsPolicy", tlsPolicy)
    def getSendingPoolName: ZIO[Any, AwsError, SendingPoolName] =
      AwsError.unwrapOptionField("sendingPoolName", sendingPoolName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpointemail.model.PutConfigurationSetDeliveryOptionsRequest
  ) extends zio.aws.pinpointemail.model.PutConfigurationSetDeliveryOptionsRequest.ReadOnly {
    override val configurationSetName: ConfigurationSetName =
      zio.aws.pinpointemail.model.primitives
        .ConfigurationSetName(impl.configurationSetName())
    override val tlsPolicy: Optional[zio.aws.pinpointemail.model.TlsPolicy] =
      zio.aws.core.internal
        .optionalFromNullable(impl.tlsPolicy())
        .map(value => zio.aws.pinpointemail.model.TlsPolicy.wrap(value))
    override val sendingPoolName: Optional[SendingPoolName] =
      zio.aws.core.internal
        .optionalFromNullable(impl.sendingPoolName())
        .map(value =>
          zio.aws.pinpointemail.model.primitives.SendingPoolName(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpointemail.model.PutConfigurationSetDeliveryOptionsRequest
  ): zio.aws.pinpointemail.model.PutConfigurationSetDeliveryOptionsRequest.ReadOnly =
    new Wrapper(impl)
}
